
# Research Software Hackathon at FORCE2019
- One day hackathon on October 15th.
- [FORCE2019 description and registration](https://www.force11.org/meetings/force2019)
- [FORCE2019 schedule](https://force2019.sched.com/)


## Description

Because modern research relies on software, it is now a cross-cutting concern
in research for multiple reasons, including communication, reproducibility,
open science/open scholarship, and citation/credit.

“Making software a first-class citizen in the scholarly world” is a one-day
hackathon bringing together a large group of stakeholders who are actively
working to improve the status of  research software in the scholarly environment.

We will discuss a variety of different approaches to make software identifiable,
citable, reusable, and reproducible, and make progress toward a common
understanding of the issues and toward a shared set of guidelines.

During the hackathon there will be  a few presentations about research software
challenges and institutional solutions.

## Logistics
Venue: Edinburgh Grosvenor Hotel- Palmerston room
1. [The agenda](agenda.md)
2. The session notes for each track:
  - [Identifiers](https://docs.google.com/document/d/1HUch2cvR4RJYc8U5eLLPIW2PPJgQvCwSO924TJHojvY/edit?usp=sharing)
  - [Metadata interoperability](https://docs.google.com/document/d/1AcIU8SSGnqCbz1vUCBXSt1VfwIBoMNW8K5p8U2FK-Vs/edit?usp=sharing)
  - [Data quality and curation](https://docs.google.com/document/d/1zt9AdRRBkWeGn2pWlssRvdpRqvjajltYdjWSbbkJrBE/edit?usp=sharing)
  - [Policies and incentives](https://docs.google.com/document/d/1T5ZH1EXB_fd1iWkO0ypLKSKG1mR-WWA6ZcfU4ydDFwQ/edit?usp=sharing)
3. Remote access- there won't be a live feed for the hackathon.
You can follow the session notes above and comment.
4. Click on the badge to join our channel  [![Gitter](https://badges.gitter.im/FORCE19_RSH/community.svg)](https://gitter.im/FORCE19_RSH/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

## Presentations
1. [research software challenges and actors](https://annex.softwareheritage.org/public/talks/2019/2019-10-15-Force2019.pdf)
  - the joint FORCE11 & RDA Software Identification WG SCID
  - the RDA Software Source Code IG
  - [the FORCE11 Software Citation Implementation WG](https://doi.org/10.6084/m9.figshare.9971672)
4. [today's agenda and activities](presentations/Agenda_presentation.pdf)
## Activities

The activities will be organised around 2-4 segments from the following list,
depending on the interests of the participants:

- Identifiers for software
    - Granularity of identification
    - Correspondence between different identifier schemas
    - Hacking the software citation graph
    - Exploring synergies
- Metadata interoperability
  - Metadata mapping (CodeMeta)
  - Connections with WikiData
  - Tooling
- Data quality and curation
  - Guidelines and checklists
  - Moderation process
  - Supporting reproducibility
- Policies and incentives
  - Institutions
  - Evaluation committees
  - National research bodies
  - Learned societies
  - Publishers


These activities will be carried out in parallel tracks, or sequentially,
depending on the number of participants.

The results of each activity will be summarised at the end of the day
during a brainstorming and conclusions session.

## Join in

We invite researchers, librarians, wikipedians, digital curators,
professional societies, publishers, archives,
indices, funders, institutions, and more generally all persons interested in
software as a research artifact to participate.

In the issues, please comment the track that interests you:
- [Identifiers](https://github.com/force11/force11-rda-scidwg/issues/1)
- [Metadata interoperability](https://github.com/force11/force11-rda-scidwg/issues/2)
- [Data quality](https://github.com/force11/force11-rda-scidwg/issues/3)
- [Policies and incentives](https://github.com/force11/force11-rda-scidwg/issues/4)


You are welcome to suggest subjects and activities on specific tracks or
as separate issues.

## Outcomes

During the day, there were 40 participants from different disciplines and representing different stakeholders.

At first we had 3 groups:
1. Identifiers & Hacking the software citation graph
2 Metadata Interoperability & eLife's Software Citation Sprint
3. Data quality & curation with Policies & Incentives.

During the day, group 3 separated into the original activities.

Each group has produced some written notes from the discussion and other outputs (depending on the group).
Here is the list and links to all the hackathon outputs by track:
- Identifiers for software
    - [Discussion notes](outcomes/track_notes_identifiers.md)
    - [preliminary identifiers crosswalk](outcomes/crosswalk_identifiers.csv)
- Metadata interoperability
  - [Discussion notes](outcomes/track_notes_metadata_interoperability.md)
  - [eLife overview](outcomes/elife_overview.pdf)
  - Tools and Hacks:
    - [CodeMeta and citation tools survey](outcomes/CodeMeta_Citation_tools_survey.csv)
    - An experiment with GitHub actions and Zenodo.     
      - [repository](https://github.com/arfon/zenodo-actions)
    - Cite my code- chrome extension.
      - [repository](https://github.com/NateWr/citemycode) on branch [codemeta_hackathon](https://github.com/NateWr/citemycode/tree/codemeta_hackathon)
    - CodeMeta Generator
      - [repository](https://forge.softwareheritage.org/source/codemeta-generator/)
      - [project board](https://forge.softwareheritage.org/tag/codemeta_generator/)
- Data quality and curation
  - [Discussion notes](outcomes/track_notes_data_quatliry_curation.md)
  - [Guidelines survey](outcomes/software_best_practices_crosswalk.csv)
  - [Group's presentation](outcomes/output_data_quality_and_curation.pdf)
- Policies and incentives
  - [Discussion notes](outcomes/track_notes_policies_incentives.md)

Also the software citation checklist produced by the SCIWG's guidelines task force was published for the first time as [version 0.9.0](https://zenodo.org/record/3479199#.XabXFZw68dU) during the hackathon.

All outcomes are available in the [outcomes](/outcomes) directory.
